package cygx

import (
	"errors"
	"fmt"
	"hongze/hz_crm_api/models/cygx"
	"hongze/hz_crm_api/services/alarm_msg"
	"hongze/hz_crm_api/utils"
	"strings"
	"time"
)

// 获取问答系列产业列表
func GetCygxAskserieVideoLabelListMap(askserieVideoIds []int) (mapResp map[int][]*cygx.IndustrialActivityGroupManagementRep) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go alarm_msg.SendAlarmMsg("获取产品内测的阅读数据，信息失败，GetCygxAskserieVideoLabelListMap Err："+err.Error(), 3)
		}
	}()
	lenArr := len(askserieVideoIds)
	if lenArr == 0 {
		return
	}
	industrialList, e := cygx.GetCygxIndustrialAskserieVideoGroupManagementList(askserieVideoIds)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取详情失败 GetCygxIndustrialAskserieVideoGroupManagementList Err" + e.Error())
		return
	}
	mapResp = make(map[int][]*cygx.IndustrialActivityGroupManagementRep, 0)
	for _, v := range industrialList {
		item := new(cygx.IndustrialActivityGroupManagementRep)
		item.IndustryName = v.IndustryName
		item.IndustrialManagementId = v.IndustrialManagementId
		item.ChartPermissionId = v.ChartPermissionId
		mapResp[v.AskserieVideoId] = append(mapResp[v.AskserieVideoId], item)
	}
	return
}

// 获取问答系列产业列表
func GetCygxAskserieVideoLabelMap(askserieVideoIds []int) (mapResp map[int]string) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go alarm_msg.SendAlarmMsg("获取产品内测的阅读数据，信息失败，GetCygxAskserieVideoLabelListMap Err："+err.Error(), 3)
		}
	}()
	lenArr := len(askserieVideoIds)
	if lenArr == 0 {
		return
	}
	industrialList, e := cygx.GetCygxIndustrialAskserieVideoGroupManagementList(askserieVideoIds)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("获取详情失败 GetCygxIndustrialAskserieVideoGroupManagementList Err" + e.Error())
		return
	}
	mapIndustryName := make(map[int][]string)
	mapResp = make(map[int]string, 0)
	for _, v := range industrialList {
		mapIndustryName[v.AskserieVideoId] = append(mapIndustryName[v.AskserieVideoId], v.IndustryName)
	}

	for k, v := range mapIndustryName {
		mapResp[k] = strings.Join(v, ",")
	}
	return
}

//func init() {
//	UpdateAskserieVideoResourceData(75)
//}

// 更新问答系列  写入首页最新  cygx_resource_data 表
func UpdateAskserieVideoResourceData(sourceId int) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go alarm_msg.SendAlarmMsg(fmt.Sprint("更新问答系列ourceId: ", sourceId, err.Error()), 2)
		}
	}()
	var source = utils.CYGX_OBJ_ASKSERIEVIDEO
	var condition string
	var pars []interface{}
	condition = ` AND publish_status = 1  AND  askserie_video_id = ?  `
	pars = append(pars, sourceId)
	total, e := cygx.GetCygxAskserieVideoCount(condition, pars)

	if e != nil {
		err = errors.New("GetCygxAskserieVideoCount, Err: " + e.Error())
		return
	}
	//如果取消发布了就做删除处理
	if total == 0 {
		e = cygx.DeleteResourceData(sourceId, source)
		if e != nil {
			err = errors.New("DeleteResourceData, Err: " + e.Error())
			return
		}
	} else {
		//判断是否存在，如果不存在就新增，存在就更新
		totalData, e := cygx.GetCygxResourceDataBySourceAndIdCount(sourceId, source)
		if e != nil {
			err = errors.New("GetCygxReportSelectionBySourceAndId, Err: " + e.Error())
			return
		}
		publishDate := time.Now().Format(utils.FormatDateTime)
		item := new(cygx.CygxResourceData)
		item.SourceId = sourceId
		item.Source = source
		item.PublishDate = publishDate
		item.CreateTime = time.Now()
		if totalData == 0 {
			_, e := cygx.AddCygxResourceData(item)
			if e != nil {
				err = errors.New("AddCygxResourceData, Err: " + e.Error())
				return
			}
		} else {
			e = cygx.UpdateResourceDataByItem(item)
			if e != nil {
				err = errors.New("UpdateResourceDataByItem, Err: " + e.Error())
				return
			}
		}
	}
	return
}
